agentle.agents.errors
=====================

.. automodule:: agentle.agents.errors

   
   .. rubric:: Exceptions

   .. autosummary::
   
      MaxToolCallsExceededError
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   max_tool_calls_exceeded_error
   tool_suspension_error
